/* eslint-disable @typescript-eslint/no-explicit-any */
import Autocomplete from "@mui/material/Autocomplete";
import TextField from "@mui/material/TextField";
import React, { useState } from "react";
import Paper from "@mui/material/Paper";
import { PaperComponentOnLoad } from "./PaperComponentOnLoad";
import { RenderTemplate } from "./RenderTemplate";
// import "@emotion/core";
import { ConditionalWrapper } from "../utility/ConditionalWrapper";
import Grid from "@mui/material/Grid";
import IconButton from "@mui/material/IconButton";
import EditIcon from "@mui/icons-material/Edit";
import CloseIcon from "@mui/icons-material/Close";
import { nanoid } from "@reduxjs/toolkit";
import { AutocompleteType, InputAux } from "../NerdInput/NerdInputEnums";
import "./NerdAutocomplete.scss";
export const NerdAutoComplete = ({ itemID, value, fullWidth, onChange, onInputChange, inputValue, label, placeholder, options = [], variant = "standard", required = false, helperText, loading, autocompleteType = AutocompleteType.CUSTOMER, icon, spacing = 1, alignItems = "center", disabled = false, 
//inputSize = 6,
autoCompleteOptionLabel = "", className, isEditable = false, }) => {
    const [open, setOpen] = useState(false);
    // const sizeWithIcons = fullWidth ? 11 : inputSize;
    //const customInputSize = fullWidth && !icon ? 12 : sizeWithIcons;
    return (React.createElement(ConditionalWrapper, { condition: icon !== undefined, wrapper: (childrenContent) => (React.createElement(Grid, { container: true, spacing: spacing, alignItems: alignItems }, childrenContent)) },
        React.createElement(React.Fragment, null,
            icon && React.createElement(Grid, { item: true }, icon),
            React.createElement(Grid, { item: true, sm: true },
                React.createElement(Autocomplete, { id: itemID, open: open, value: value, fullWidth: fullWidth, onOpen: () => setOpen(true), onClose: () => setOpen(false), onChange: onChange, onInputChange: onInputChange, inputValue: inputValue, options: options, clearIcon: null, getOptionLabel: (option) => getOptionLabel(option, autoCompleteOptionLabel), onKeyDown: (event) => {
                        if (event.key === "Enter") {
                            // Prevent's default 'Enter' behavior.
                            event.preventDefault();
                            // handler code
                        }
                    }, renderInput: (params) => (React.createElement(TextField, Object.assign({}, params, { label: label, variant: variant, placeholder: placeholder, InputLabelProps: {
                            shrink: true,
                        }, InputProps: Object.assign(Object.assign({}, params.InputProps), { endAdornment: null }), helperText: renderHelperText(required, helperText), required: required, fullWidth: true }))), renderOption: (props, option) => {
                        return (React.createElement(RenderTemplate, Object.assign({}, props, { option: option, autocompleteType: autocompleteType, optionsArray: options })));
                    }, PaperComponent: (props) => {
                        if (!inputValue || loading) {
                            return (React.createElement(PaperComponentOnLoad, Object.assign({}, { props, inputValue, autocompleteType, loading }, { key: nanoid(), className: className ? "autocompleteSmall" : "" })));
                        }
                        return (React.createElement(Paper, Object.assign({}, props, { key: nanoid(), className: className ? "autocompleteSmall" : "" }), props.children));
                    } })),
            icon && (React.createElement(Grid, { item: true, flexDirection: "column", display: "flex" },
                isEditable && (React.createElement(IconButton, { disabled: disabled, size: "small", onClick: (event) => {
                        setOpen(false);
                        onChange(event, "");
                        onInputChange(event, "");
                    } },
                    React.createElement(EditIcon, { fontSize: "small" }))),
                React.createElement(IconButton, { disabled: disabled, size: "small", onClick: (event) => {
                        setOpen(false);
                        onChange(event, "");
                        onInputChange(event, "");
                    } },
                    React.createElement(CloseIcon, { fontSize: "small" })))))));
};
/**
 *
 * @param required
 * @param helperText
 */
function renderHelperText(required, helperText) {
    if (!helperText) {
        return "";
    }
    return required ? InputAux.REQUIRED : helperText;
}
/**
 *
 * @param option
 * @param autoCompleteOptionLabel
 */
function getOptionLabel(option, autoCompleteOptionLabel) {
    if (typeof option === "string") {
        return option;
    }
    if (typeof option === "object" && Object.keys(option).length > 0) {
        return option[autoCompleteOptionLabel];
    }
    return "";
}
