import Box from "@mui/system/Box";
import React from "react";
import CorporateFareIcon from "@mui/icons-material/CorporateFare";
import CardHeader from "@mui/material/CardHeader";
import Avatar from "@mui/material/Avatar";
import LocationOnTwoToneIcon from "@mui/icons-material/LocationOnTwoTone";
import { blue, grey } from "@mui/material/colors";
import { nanoid } from "@reduxjs/toolkit";
import { AutocompleteType } from "../NerdInput/NerdInputEnums";
import Grid from "@mui/material/Grid";
import Typography from "@mui/material/Typography";
import Divider from "@mui/material/Divider";
export const RenderTemplate = ({ props, option, autocompleteType, className = "", optionsArray = [], onClick, }) => {
    const ListFoot = () => {
        return optionsArray[optionsArray.length - 1] === option ? (React.createElement(React.Fragment, null,
            React.createElement(Divider, null),
            React.createElement(Grid, { container: true, alignItems: "center", justifyContent: "center" },
                React.createElement(Grid, { item: true, py: 1 },
                    React.createElement(Typography, { display: "block", variant: "caption", color: "textSecondary" },
                        "Powered by ",
                        React.createElement("b", null, "Google"),
                        " and ",
                        React.createElement("b", null, "Archer")))))) : null;
    };
    return (React.createElement(React.Fragment, null,
        React.createElement(Box, Object.assign({ key: nanoid(), component: "li", sx: {
                backgroundColor: "transparent",
                svg: { flexShrink: 0, color: "white" },
                cursor: "pointer",
                "&:hover": {
                    backgroundColor: "rgba(0, 0, 0, 0.08)",
                },
            } }, props, { className: className, onClick: onClick }),
            React.createElement(CardHeader, { avatar: React.createElement(Avatar, { sx: {
                        bgcolor: setTemplateIconColorByType(autocompleteType, option),
                    }, "aria-label": autocompleteType }, setTemplateIconByType(autocompleteType)), title: setTemplateTitle(autocompleteType, option), titleTypographyProps: { fontWeight: "500", variant: "body1" }, subheader: setTemplateContentByType(autocompleteType, option), sx: {
                    py: 1,
                    px: 1,
                } })),
        React.createElement(ListFoot, null)));
};
/**
 *
 * @param type
 */
function setTemplateIconByType(type) {
    switch (type) {
        case AutocompleteType.CUSTOMER:
            return React.createElement(CorporateFareIcon, { fontSize: "medium" });
        case AutocompleteType.ADDRESS:
            return React.createElement(LocationOnTwoToneIcon, { fontSize: "medium" });
        default:
            return React.createElement(CorporateFareIcon, { fontSize: "medium" });
    }
}
/**
 *
 * @param type
 * @param option
 */
function setTemplateIconColorByType(type, option) {
    switch (type) {
        case AutocompleteType.CUSTOMER:
            return blue[500];
        case AutocompleteType.ADDRESS:
            if (option.name) {
                return blue[500];
            }
            return grey[500];
        default:
            return blue[500];
    }
}
/**
 *
 * @param type
 * @param option
 */
function setTemplateContentByType(type, option) {
    const auxContentCredit = option.credit_on_hold ? " - ( Credit Hold )" : "";
    const auxContentInactivity = option.inactivity_hold
        ? " - ( Inactivity Hold )"
        : "";
    switch (type) {
        case AutocompleteType.CUSTOMER:
            return `${option.line1} ${option.state} ${option.zip} ${auxContentCredit} ${auxContentInactivity}`;
        case AutocompleteType.ADDRESS:
            if (option.structured_formatting) {
                return `${option.structured_formatting.secondary_text}`;
            }
            return option.name;
        default:
            return "";
    }
}
/**
 *
 * @param type
 * @param option
 */
function setTemplateTitle(type, option) {
    switch (type) {
        case AutocompleteType.CUSTOMER:
            return `${option.name}`;
        case AutocompleteType.ADDRESS:
            if (option.structured_formatting) {
                return `${option.structured_formatting.main_text}`;
            }
            return option.name;
        default:
            return "";
    }
}
