import Box from "@mui/material/Box";
import Button from "@mui/material/Button";
import Dialog from "@mui/material/Dialog";
import DialogActions from "@mui/material/DialogActions";
import DialogContent from "@mui/material/DialogContent";
import DialogContentText from "@mui/material/DialogContentText";
import DialogTitle from "@mui/material/DialogTitle";
import Stack from "@mui/material/Stack";
import React from "react";
import { colorSwitch, NerdIcon, setCustomIconDefinition, } from "../../shared/NerdIcon";
import BorderLinearProgress from "../../shared/Progess/BorderLinearProgress";
import "../NerdNotifier.scss";
/**
 *
 * @param {NerdNotificationProps & openHookAction} param0 Component props
 * @returns {JSX.Element} Intrusive nerdNotifier
 */
export function Intrusive({ title, subtitle, body, icon, actions, severity = "info", open, iconColor, autoHideDuration = 5000, autohide = true, showIcon = true, onHandleClose, unstyled = true, actionPrimaryProps = {
    variant: "text",
    color: "primary",
}, actionSecondaryProps = {
    variant: "text",
    color: "inherit",
}, }) {
    var _a;
    const [progress, setProgress] = React.useState(0);
    const timer = React.useRef(0);
    const handleClose = (_event, reason) => {
        if (reason === "clickaway" ||
            reason === "escapeKeyDown" ||
            reason === "backdropClick") {
            return;
        }
        onHandleClose(false);
    };
    React.useEffect(() => {
        timer.current = window.setInterval(() => {
            setProgress((prevProgress) => prevProgress >= 100 ? 0 : prevProgress + 10);
        }, autoHideDuration / 10);
        return () => {
            clearInterval(timer.current);
        };
    }, []);
    React.useEffect(() => {
        if (progress >= 100 && autohide) {
            onHandleClose(false);
        }
    }, [progress, autohide, open]);
    const severityIcon = setCustomIconDefinition(((_a = severityIcons(severity)) !== null && _a !== void 0 ? _a : "exclamation-circle"));
    return (React.createElement(Dialog, { open: open, onClose: handleClose, "aria-labelledby": "alert-dialog-title", "aria-describedby": "alert-dialog-description", keepMounted: true, transitionDuration: 1000, classes: {
            paper: "NerdNotifierIntrusivePaper",
        } },
        React.createElement(Stack, { spacing: 1 },
            autohide && !actions && (React.createElement(BorderLinearProgress, { variant: "determinate", value: progress, color: severity })),
            showIcon && (React.createElement(Box, { className: "IntrusiveIcon" },
                typeof icon === "string" ? (React.createElement(NerdIcon, { icon: severityIcon, severity: severity, iconColor: iconColor })) : (icon),
                severity && !icon && (React.createElement(NerdIcon, { icon: severityIcon, severity: severity, iconColor: colorSwitch(severity) })))),
            title && React.createElement(DialogTitle, { id: "alert-dialog-title" }, title),
            unstyled ? (React.createElement(DialogContent, null,
                subtitle && (React.createElement(DialogContentText, { id: "alert-dialog-description" }, subtitle)),
                body)) : (React.createElement(React.Fragment, null,
                subtitle,
                body)),
            !autohide && (React.createElement(DialogActions, null,
                React.createElement(Button, Object.assign({ onClick: handleClose }, actionSecondaryProps), "Cancel"),
                React.createElement(Button, Object.assign({ onClick: handleClose }, actionPrimaryProps), "Ok"))))));
}
/**
 *
 * @param severityText
 */
function severityIcons(severityText) {
    switch (severityText) {
        case "error":
            return "times";
        case "info":
            return "exclamation";
        case "success":
            return "check";
        case "warning":
            return "exclamation-triangle";
        default:
            return "";
    }
}
