import React from "react";
import MuiAlert from "@mui/material/Alert";
import Slide from "@mui/material/Slide";
import Snackbar from "@mui/material/Snackbar";
import { Stack, Typography } from "@mui/material";
import Box from "@mui/system/Box";
import BorderLinearProgress from "../../shared/Progess/BorderLinearProgress";
let direction = undefined;
/**
 *
 * @param {NerdNotificationProps & openHookAction} param0 components props
 * @returns {JSX.Element} NonIntrusive nerdNotifier
 */
export function NonIntrusive({ uuid, title, transition = "up", severity = "info", subtitle, body, position = {
    vertical: "bottom",
    horizontal: "right",
}, actions, autoHideDuration = 5000, autohide = true, open, handleClose, icon, color, }) {
    direction = transition;
    const [progress, setProgress] = React.useState(0);
    const timer = React.useRef(0);
    React.useEffect(() => {
        timer.current = window.setInterval(() => {
            setProgress((prevProgress) => prevProgress >= 100 ? 0 : prevProgress + 10);
        }, autoHideDuration / 10);
        return () => {
            clearInterval(timer.current);
        };
    }, []);
    React.useEffect(() => {
        if (progress >= 100 && autohide) {
            handleClose();
        }
    }, [progress, autohide]);
    if (icon) {
        return (React.createElement(Alert, { severity: "warning", className: "nonIntrusive--unkown" }, "Unkown"));
    }
    return (React.createElement(Box, { component: "div", id: uuid },
        React.createElement(Snackbar, { open: open, autoHideDuration: autohide ? autoHideDuration : null, TransitionComponent: Transition, anchorOrigin: position },
            React.createElement(Stack, { spacing: 1 },
                autohide && (React.createElement(BorderLinearProgress, { variant: "determinate", value: progress, color: severity })),
                React.createElement(Alert, { severity: severity, sx: { width: "100%", alignItems: "center", backgroundColor: color }, action: actions, onClose: handleClose },
                    title && React.createElement(Typography, { variant: "body1" }, title),
                    subtitle && React.createElement(Typography, { variant: "body2" }, subtitle),
                    body && React.createElement(Typography, { variant: "caption" }, body))))));
}
const Alert = React.forwardRef(function Alert(props, ref) {
    return React.createElement(MuiAlert, Object.assign({ ref: ref, variant: "filled" }, props));
});
/**
 *
 * @param {TransitionProps} props Component props
 * @returns {JSX.Element} Transition Component
 */
function Transition(props) {
    return React.createElement(Slide, Object.assign({}, props, { direction: direction }));
}
