"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Intrusive = void 0;
const Box_1 = __importDefault(require("@mui/material/Box"));
const Button_1 = __importDefault(require("@mui/material/Button"));
const Dialog_1 = __importDefault(require("@mui/material/Dialog"));
const DialogActions_1 = __importDefault(require("@mui/material/DialogActions"));
const DialogContent_1 = __importDefault(require("@mui/material/DialogContent"));
const DialogContentText_1 = __importDefault(require("@mui/material/DialogContentText"));
const DialogTitle_1 = __importDefault(require("@mui/material/DialogTitle"));
const Stack_1 = __importDefault(require("@mui/material/Stack"));
const react_1 = __importDefault(require("react"));
const NerdIcon_1 = require("../../shared/NerdIcon");
const BorderLinearProgress_1 = __importDefault(require("../../shared/Progess/BorderLinearProgress"));
require("../NerdNotifier.scss");
/**
 *
 * @param {NerdNotificationProps & openHookAction} param0 Component props
 * @returns {JSX.Element} Intrusive nerdNotifier
 */
function Intrusive({ title, subtitle, body, icon, actions, severity = "info", open, iconColor, autoHideDuration = 5000, autohide = true, showIcon = true, onHandleClose, unstyled = true, actionPrimaryProps = {
    variant: "text",
    color: "primary",
}, actionSecondaryProps = {
    variant: "text",
    color: "inherit",
}, }) {
    var _a;
    const [progress, setProgress] = react_1.default.useState(0);
    const timer = react_1.default.useRef(0);
    const handleClose = (_event, reason) => {
        if (reason === "clickaway" ||
            reason === "escapeKeyDown" ||
            reason === "backdropClick") {
            return;
        }
        onHandleClose(false);
    };
    react_1.default.useEffect(() => {
        timer.current = window.setInterval(() => {
            setProgress((prevProgress) => prevProgress >= 100 ? 0 : prevProgress + 10);
        }, autoHideDuration / 10);
        return () => {
            clearInterval(timer.current);
        };
    }, []);
    react_1.default.useEffect(() => {
        if (progress >= 100 && autohide) {
            onHandleClose(false);
        }
    }, [progress, autohide, open]);
    const severityIcon = (0, NerdIcon_1.setCustomIconDefinition)(((_a = severityIcons(severity)) !== null && _a !== void 0 ? _a : "exclamation-circle"));
    return (react_1.default.createElement(Dialog_1.default, { open: open, onClose: handleClose, "aria-labelledby": "alert-dialog-title", "aria-describedby": "alert-dialog-description", keepMounted: true, transitionDuration: 1000, classes: {
            paper: "NerdNotifierIntrusivePaper",
        } },
        react_1.default.createElement(Stack_1.default, { spacing: 1 },
            autohide && !actions && (react_1.default.createElement(BorderLinearProgress_1.default, { variant: "determinate", value: progress, color: severity })),
            showIcon && (react_1.default.createElement(Box_1.default, { className: "IntrusiveIcon" },
                typeof icon === "string" ? (react_1.default.createElement(NerdIcon_1.NerdIcon, { icon: severityIcon, severity: severity, iconColor: iconColor })) : (icon),
                severity && !icon && (react_1.default.createElement(NerdIcon_1.NerdIcon, { icon: severityIcon, severity: severity, iconColor: (0, NerdIcon_1.colorSwitch)(severity) })))),
            title && react_1.default.createElement(DialogTitle_1.default, { id: "alert-dialog-title" }, title),
            unstyled ? (react_1.default.createElement(DialogContent_1.default, null,
                subtitle && (react_1.default.createElement(DialogContentText_1.default, { id: "alert-dialog-description" }, subtitle)),
                body)) : (react_1.default.createElement(react_1.default.Fragment, null,
                subtitle,
                body)),
            !autohide && (react_1.default.createElement(DialogActions_1.default, null,
                react_1.default.createElement(Button_1.default, Object.assign({ onClick: handleClose }, actionSecondaryProps), "Cancel"),
                react_1.default.createElement(Button_1.default, Object.assign({ onClick: handleClose }, actionPrimaryProps), "Ok"))))));
}
exports.Intrusive = Intrusive;
/**
 *
 * @param severityText
 */
function severityIcons(severityText) {
    switch (severityText) {
        case "error":
            return "times";
        case "info":
            return "exclamation";
        case "success":
            return "check";
        case "warning":
            return "exclamation-triangle";
        default:
            return "";
    }
}
