"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NonIntrusive = void 0;
const react_1 = __importDefault(require("react"));
const Alert_1 = __importDefault(require("@mui/material/Alert"));
const Slide_1 = __importDefault(require("@mui/material/Slide"));
const Snackbar_1 = __importDefault(require("@mui/material/Snackbar"));
const material_1 = require("@mui/material");
const Box_1 = __importDefault(require("@mui/system/Box"));
const BorderLinearProgress_1 = __importDefault(require("../../shared/Progess/BorderLinearProgress"));
let direction = undefined;
/**
 *
 * @param {NerdNotificationProps & openHookAction} param0 components props
 * @returns {JSX.Element} NonIntrusive nerdNotifier
 */
function NonIntrusive({ uuid, title, transition = "up", severity = "info", subtitle, body, position = {
    vertical: "bottom",
    horizontal: "right",
}, actions, autoHideDuration = 5000, autohide = true, open, handleClose, icon, color, }) {
    direction = transition;
    const [progress, setProgress] = react_1.default.useState(0);
    const timer = react_1.default.useRef(0);
    react_1.default.useEffect(() => {
        timer.current = window.setInterval(() => {
            setProgress((prevProgress) => prevProgress >= 100 ? 0 : prevProgress + 10);
        }, autoHideDuration / 10);
        return () => {
            clearInterval(timer.current);
        };
    }, []);
    react_1.default.useEffect(() => {
        if (progress >= 100 && autohide) {
            handleClose();
        }
    }, [progress, autohide]);
    if (icon) {
        return (react_1.default.createElement(Alert, { severity: "warning", className: "nonIntrusive--unkown" }, "Unkown"));
    }
    return (react_1.default.createElement(Box_1.default, { component: "div", id: uuid },
        react_1.default.createElement(Snackbar_1.default, { open: open, autoHideDuration: autohide ? autoHideDuration : null, TransitionComponent: Transition, anchorOrigin: position },
            react_1.default.createElement(material_1.Stack, { spacing: 1 },
                autohide && (react_1.default.createElement(BorderLinearProgress_1.default, { variant: "determinate", value: progress, color: severity })),
                react_1.default.createElement(Alert, { severity: severity, sx: { width: "100%", alignItems: "center", backgroundColor: color }, action: actions, onClose: handleClose },
                    title && react_1.default.createElement(material_1.Typography, { variant: "body1" }, title),
                    subtitle && react_1.default.createElement(material_1.Typography, { variant: "body2" }, subtitle),
                    body && react_1.default.createElement(material_1.Typography, { variant: "caption" }, body))))));
}
exports.NonIntrusive = NonIntrusive;
const Alert = react_1.default.forwardRef(function Alert(props, ref) {
    return react_1.default.createElement(Alert_1.default, Object.assign({ ref: ref, variant: "filled" }, props));
});
/**
 *
 * @param {TransitionProps} props Component props
 * @returns {JSX.Element} Transition Component
 */
function Transition(props) {
    return react_1.default.createElement(Slide_1.default, Object.assign({}, props, { direction: direction }));
}
