import React from "react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { findIconDefinition, library, } from "@fortawesome/fontawesome-svg-core";
import { fas } from "@fortawesome/free-solid-svg-icons";
import Box from "@mui/material/Box";
library.add(fas);
const NerdFontAwesomeIcon = React.forwardRef((props, ref) => {
    const { icon, severity, iconColor } = props;
    if (!icon) {
        return null;
    }
    return (React.createElement(Box, { mt: 2, mx: "auto", ref: ref }, typeof icon === "string" ? (setCustomIconString({ icon, severity, iconColor })) : (React.createElement(FontAwesomeIcon, { icon: icon, size: "3x", color: iconColor !== null && iconColor !== void 0 ? iconColor : "#0288d1" }))));
});
NerdFontAwesomeIcon.displayName = "NerdFontAwesomeIcon";
export { NerdFontAwesomeIcon };
/**
 * @param {object} root0 props
 * @param {string} root0.icon Icon
 * @param {string} root0.iconColor Icon color
 * @param {string} root0.severity Severity
 * @returns {JSX.Element} Custom Icon String
 */
function setCustomIconString({ icon, iconColor, severity, }) {
    return (React.createElement(FontAwesomeIcon, { icon: setCustomIconDefinition(icon), color: iconColor && iconColor !== ""
            ? iconColor
            : colorSwitch(severity || "info"), size: "3x" }));
}
/**
 * @param {IconName} icon Icon
 * @returns {IconDefinition} Custom Icon definition
 */
export function setCustomIconDefinition(icon) {
    const iconLookup = {
        prefix: "fas",
        iconName: icon,
    };
    const customIconDefinition = findIconDefinition(iconLookup);
    return customIconDefinition;
}
export const colorSwitch = (color) => ({
    error: "#d32f2f",
    info: "#0288d1",
    success: "#2e7d32",
    warning: "#ed6c02",
}[color]);
